package com.chinaitop.depot.device.service.impl;

import java.util.Date;
import java.util.List;

import javax.annotation.Resource;

import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import com.chinaitop.depot.device.mapper.StorageJsglMapper;
import com.chinaitop.depot.device.model.StorageJsgl;
import com.chinaitop.depot.device.model.StorageJsglExample;
import com.chinaitop.depot.device.model.StorageJsglExample.Criteria;
import com.chinaitop.depot.device.service.StorageJsglService;
import com.chinaitop.depot.feignClients.service.DepotBusinessFeignService;
import com.chinaitop.depot.utils.ParameterUtil;

@Service
public class StorageJsglServiceImpl implements StorageJsglService {

	@Resource
	private StorageJsglMapper storageJsglMapper;
	@Resource
	private DepotBusinessFeignService depotBusinessFeignService;

	@Override
	public List<StorageJsgl> findByCondition(Integer houseId, Integer warehouseId, Integer orgId, String jslx, String ywlx, String htbh) throws Exception {
		StorageJsglExample example = new StorageJsglExample();
		Criteria criteria = example.createCriteria();
		if (null != houseId) {
			criteria.andHouseIdEqualTo(houseId);
		}
		if (null != warehouseId) {
			criteria.andWarehouseIdEqualTo(warehouseId);
		}
		if (null != orgId) {
			criteria.andOrgIdEqualTo(orgId);
		}
		if (StringUtils.isNotBlank(jslx)) {
			criteria.andJslxEqualTo(jslx);
		}
		if (StringUtils.isNotBlank(ywlx)) {
			criteria.andYwlxEqualTo(ywlx);
		}
		if (StringUtils.isNotBlank(htbh)) {
			criteria.andHtbhEqualTo(htbh);
		}
		example.setOrderByClause("bcjssj desc");
		List<StorageJsgl> list = storageJsglMapper.selectByExample(example);
		return list;
	}

	@Override
	public StorageJsgl findByParmaryKey(String id) throws Exception {
		StorageJsgl storageJsgl = storageJsglMapper.selectByPrimaryKey(id);
		return storageJsgl;
	}

	@Override
	public void addStorageJsgl(StorageJsgl storageJsgl) throws Exception {

		String id = ParameterUtil.getUuid();
		Date date = new Date();
		storageJsgl.setId(id);
		storageJsgl.setCreateTime(date);
		storageJsgl.setUpdateTime(date);

		storageJsglMapper.insert(storageJsgl);
	}

	@Override
	public void updateStorageJsgl(StorageJsgl storageJsgl) throws Exception {
		Date date = new Date();
		storageJsgl.setUpdateTime(date);
		storageJsglMapper.updateByPrimaryKeyWithBLOBs(storageJsgl);
	}

	@Override
	public void removeStorageJsgl(String id) throws Exception {
		storageJsglMapper.deleteByPrimaryKey(id);
	}

	@Override
	@Transactional(rollbackFor = Exception.class)
	public void saveOrUpdate(StorageJsgl storageJsgl) throws Exception {
		//生成发票号集合
		String fpText = getFpText(storageJsgl);
		storageJsgl.setFpText(fpText);

		if (StringUtils.isBlank(storageJsgl.getId())) {
			addStorageJsgl(storageJsgl);
		} else {
			updateStorageJsgl(storageJsgl);
		}
		if ("1".equals(storageJsgl.getDataStatus()) && "1".equals(storageJsgl.getYwlx())) {
			depotBusinessFeignService.updateYjssl(Integer.parseInt(storageJsgl.getHtid()), storageJsgl.getBcjssl().toString());
		}
	}

	/**
	 * 生成并组合发票集合
	 * @param storageJsgl
	 * @return
	 * @throws Exception
	 */
	private String getFpText(StorageJsgl storageJsgl) throws Exception {
		StringBuffer sbf = new StringBuffer(50);
		if (StringUtils.isNotBlank(storageJsgl.getFpStart()) && StringUtils.isNotBlank(storageJsgl.getFpEnd())) {
			int fp_start = Integer.parseInt(storageJsgl.getFpStart());
			int fp_end = Integer.parseInt(storageJsgl.getFpEnd());
			int len = storageJsgl.getFpStart().length();
			for (int i = fp_start; i <= fp_end; i++) {
				sbf.append(String.format("%0"+len+"d", i)).append(",");
			}
		}

		if (StringUtils.isNotBlank(storageJsgl.getFps())) {
			sbf.append(storageJsgl.getFps().replace("，", ","));
		}
		String fpText = sbf.toString();
		if (fpText.length() > 0 && fpText.endsWith(",")) {
			fpText = sbf.toString().substring(0, sbf.toString().length()-1);
		}
		return fpText;
	}

}
